==> plasma-desktop-5.10.2.tar.xz: plasma-desktop-5.10.2/applets/kicker/plugin/funnelmodel.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef FUNNELMODEL_H
#define FUNNELMODEL_H

#include "forwardingmodel.h"

class FunnelModel : public ForwardingModel
{
    Q_OBJECT

    public:
        explicit FunnelModel(QObject *parent = 0);
        ~FunnelModel();

        void setSourceModel(QAbstractItemModel *model);
};

#endif

==> plasma-desktop_5.12.9.1.orig.tar.xz: plasma-desktop-5.12.9.1/applets/kicker/plugin/funnelmodel.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef FUNNELMODEL_H
#define FUNNELMODEL_H

#include "forwardingmodel.h"

class FunnelModel : public ForwardingModel
{
    Q_OBJECT

    public:
        explicit FunnelModel(QObject *parent = 0);
        ~FunnelModel();

        void setSourceModel(QAbstractItemModel *model) Q_DECL_OVERRIDE;
};

#endif
